@@ -66,7 +66,7 @@ static gint gnome_db_basic_form_signals[LAST_SIGNAL] = { 0 };
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
-guint
+GType
 gnome_db_basic_form_get_type (void)
 {
 	static GType type = 0;
