@@ -135,7 +135,7 @@ GQuark gnome_db_dict_error_quark (void)
 }
 
 
-guint
+GType
 gnome_db_dict_get_type (void)
 {
 	static GType type = 0;
@@ -1693,17 +1693,17 @@ gnome_db_dict_compute_xml_filename (GnomeDbDict *dict, const gchar *datasource,
  *      an argument */
 
 /* same as for libgda */
-#define LIBGDA_USER_DICTIG_DIR G_DIR_SEPARATOR_S ".libgda"
+#define LIBGDA_USER_CONFIG_DIR G_DIR_SEPARATOR_S ".libgda"
 
 	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
 	g_return_val_if_fail (dict->priv, NULL);
 	g_return_val_if_fail (datasource && *datasource, NULL);
 
 	if (!app_id)
-		str = g_strdup_printf ("%s%sDICT_%s_default.xml", g_get_home_dir (), LIBGDA_USER_DICTIG_DIR G_DIR_SEPARATOR_S,
+		str = g_strdup_printf ("%s%sDICT_%s_default.xml", g_get_home_dir (), LIBGDA_USER_CONFIG_DIR G_DIR_SEPARATOR_S,
 				       datasource);
 	else
-		str = g_strdup_printf ("%s%sDICT_%s_%s.xml", g_get_home_dir (), LIBGDA_USER_DICTIG_DIR G_DIR_SEPARATOR_S,
+		str = g_strdup_printf ("%s%sDICT_%s_%s.xml", g_get_home_dir (), LIBGDA_USER_CONFIG_DIR G_DIR_SEPARATOR_S,
 				       datasource, app_id);
 
 	/* create an empty file with that name */
@@ -1711,7 +1711,7 @@ gnome_db_dict_compute_xml_filename (GnomeDbDict *dict, const gchar *datasource,
 		gchar *dirpath;
 		FILE *fp;
 		
-		dirpath = g_strdup_printf ("%s%s", g_get_home_dir (), LIBGDA_USER_DICTIG_DIR);
+		dirpath = g_strdup_printf ("%s%s", g_get_home_dir (), LIBGDA_USER_CONFIG_DIR);
 		if (!g_file_test (dirpath, G_FILE_TEST_IS_DIR)){
 			if (mkdir (dirpath, 0700)) {
 				g_set_error (error,
